@@ -14,8 +14,9 @@ function (object, object2, test = TRUE, ...) {
     if (test && df < 0)
         stop("'object' should be nested in 'object2'.\n")
     out <- list(nam0 = deparse(substitute(object)), L0 = L0, aic0 = AIC(object), 
-        bic0 = AIC(object, k = log(attr(L0, "nobs"))), nam1 = deparse(substitute(object2)), L1 = L1, aic1 = AIC(object2), 
-        bic1 = AIC(object2, k = log(attr(L1, "nobs"))), df = df, test = test)
+        bic0 = AIC(object, k = log(attr(L0, "nobs"))), nam1 = deparse(substitute(object2)), 
+            L1 = L1, aic1 = AIC(object2), bic1 = AIC(object2, k = log(attr(L1, "nobs"))), 
+            df = df, test = test)
     if (test) {
         LRT <- - 2 * (L0 - L1)
         attributes(LRT) <- NULL
