@@ -1,5 +1,5 @@
 weibullAFTGH.fit <-
-function (x, y, id, initial.values, scaleWB, control) {
+function (x, y, id, initial.values, scaleWB, parameterization, derivForm, control) {
     # response vectors
     logT <- as.vector(y$logT)
     d <- as.vector(y$d)
@@ -8,14 +8,28 @@ function (x, y, id, initial.values, scaleWB, control) {
     X <- x$X
     Xtime <- x$Xtime
     Xs <- x$Xs
+    Xtime.deriv <- x$Xtime.deriv
+    Xs.deriv <- x$Xs.deriv    
     Z <- x$Z
     Ztime <- x$Ztime
     Zs <- x$Zs
+    Ztime.deriv <- x$Ztime.deriv
+    Zs.deriv <- x$Zs.deriv
     W1 <- x$W
     WW <- if (is.null(W1)) as.matrix(rep(1, length(logT))) else cbind(1, W1)
-    dimnames(X) <- dimnames(Xtime) <- dimnames(Xs) <- dimnames(Z) <- dimnames(Ztime) <- dimnames(Zs) <- dimnames(WW) <- NULL
-    attr(X, "assign") <- attr(X, "contrasts") <- attr(Xtime, "assign") <- attr(Xtime, "contrasts") <- NULL
-    attr(Xs, "assign") <- attr(Xs, "contrasts") <- attr(Zs, "assign") <- attr(Zs, "contrasts") <- attr(Z, "assign") <- attr(Ztime, "assign") <- NULL
+    X <- dropAttr(X); Z <- dropAttr(Z); WW <- dropAttr(WW)
+    if (parameterization == "value") {
+        Xtime <- dropAttr(Xtime); Ztime <- dropAttr(Ztime); Xs <- dropAttr(Xs); Zs <- dropAttr(Zs)
+    } else if (parameterization == "slope") {
+        Xtime.deriv <- dropAttr(Xtime.deriv); Ztime.deriv <- dropAttr(Ztime.deriv)
+        Xs.deriv <- dropAttr(Xs.deriv); Zs.deriv <- dropAttr(Zs.deriv)
+    } else {
+        Xtime <- dropAttr(Xtime); Ztime <- dropAttr(Ztime); Xs <- dropAttr(Xs); Zs <- dropAttr(Zs)
+        Xtime.deriv <- dropAttr(Xtime.deriv); Ztime.deriv <- dropAttr(Ztime.deriv)
+        Xs.deriv <- dropAttr(Xs.deriv); Zs.deriv <- dropAttr(Zs.deriv)
+    }
+    indFixed <- derivForm$indFixed
+    indRandom <- derivForm$indRandom
     # sample size settings
     ncx <- ncol(X)
     ncz <- ncol(Z)
@@ -38,8 +52,19 @@ function (x, y, id, initial.values, scaleWB, control) {
     b <- sqrt(2) * t(control$inv.chol.VC %*% t(b)); dimnames(b) <- NULL
     b2 <- if (ncz == 1) b * b else t(apply(b, 1, function (x) x %o% x))
     Ztb <- Z %*% t(b)
-    Ztime.b <- Ztime %*% t(b)
-    Zsb <- Zs %*% t(b)
+    if (parameterization %in% c("value", "both")) {
+        Ztime.b <- Ztime %*% t(b)
+        Zsb <- Zs %*% t(b)
+    }
+    if (parameterization %in% c("slope", "both")) {
+        if (length(indRandom) > 1 || indRandom) {
+            Ztime.b.deriv <- Ztime.deriv %*% t(b[, indRandom, drop = FALSE])
+            Zsb.deriv <- Zs.deriv %*% t(b[, indRandom, drop = FALSE])
+        } else {
+            Ztime.b.deriv <- matrix(0, nrow(Ztime.deriv), k)
+            Zsb.deriv <- matrix(0, nrow(Zs.deriv), k)
+        }
+    }
     # Gauss-Kronrod rule
     st <- x$st
     log.st <- log(st)
@@ -51,6 +76,7 @@ function (x, y, id, initial.values, scaleWB, control) {
     sigma <- initial.values$sigma
     gammas <- as.vector(initial.values$gammas)
     alpha <- as.vector(initial.values$alpha)
+    Dalpha <- as.vector(initial.values$Dalpha)
     sigma.t <- if (is.null(scaleWB)) initial.values$sigma.t else scaleWB
     D <- initial.values$D
     diag.D <- !is.matrix(D)
@@ -64,24 +90,32 @@ function (x, y, id, initial.values, scaleWB, control) {
     # EM iterations
     iter <- control$iter.EM
     Y.mat <- matrix(0, iter + 1, ncx + 1)
-    T.mat <- matrix(0, iter + 1, ncww + 2)
+    T.mat <- matrix(0, iter + 1, switch(parameterization, "value" = , "slope" = ncww + 2, "both" = ncww + 3))
     B.mat <- if (diag.D) matrix(0, iter + 1, ncz) else matrix(0, iter + 1, ncz * ncz)
     lgLik <- numeric(iter + 1)
     conv <- FALSE
     for (it in 1:iter) {
         # save parameter values in matrix
         Y.mat[it, ] <- c(betas, sigma)
-        T.mat[it, ] <- c(gammas, alpha, sigma.t)
+        T.mat[it, ] <- switch(parameterization, "value" = c(gammas, alpha, sigma.t), 
+            "slope" = c(gammas, Dalpha, sigma.t), "both" = c(gammas, alpha, Dalpha, sigma.t))
         B.mat[it,] <- D
         
         # linear predictors
         eta.yx <- as.vector(X %*% betas)
-        eta.yxT <- as.vector(Xtime %*% betas)
         eta.tw <- as.vector(WW %*% gammas)
-        Y <- eta.yxT + Ztime.b
-        Ys <- as.vector(Xs %*% betas) + Zsb
-        eta.t <- eta.tw + alpha * Y
-        eta.s <- alpha * Ys
+        if (parameterization %in% c("value", "both")) {
+            Y <- as.vector(Xtime %*% betas) + Ztime.b
+            Ys <- as.vector(Xs %*% betas) + Zsb
+            eta.t <- eta.tw + alpha * Y
+            eta.s <- alpha * Ys
+        }
+        if (parameterization %in% c("slope", "both")) {
+            Y.deriv <- as.vector(Xtime.deriv %*% betas[indFixed]) + Ztime.b.deriv
+            Ys.deriv <- as.vector(Xs.deriv %*% betas[indFixed]) + Zsb.deriv
+            eta.t <- if (parameterization == "both") eta.t + Dalpha * Y.deriv else eta.tw + Dalpha * Y.deriv
+            eta.s <- if (parameterization == "both") eta.s + Dalpha * Ys.deriv else Dalpha * Ys.deriv
+        }
         
         # E-step
         mu.y <- eta.yx + Ztb
@@ -112,7 +146,7 @@ function (x, y, id, initial.values, scaleWB, control) {
         
         # compute log-likelihood
         log.p.yt <- log(p.yt)
-        lgLik[it] <- sum(log.p.yt[is.finite(log.p.yt)], na.rm = TRUE)
+        lgLik[it] <- sum(log.p.yt[is.finite(log.p.yt)])
         
         # print results if verbose
         if (control$verbose) {
@@ -121,7 +155,10 @@ function (x, y, id, initial.values, scaleWB, control) {
             cat("betas:", round(betas, 4), "\n")
             cat("sigma:", round(sigma, 4), "\n")
             cat("gammas:", -round(gammas, 4), "\n")
-            cat("alpha:", -round(alpha, 4), "\n")
+            if (parameterization %in% c("value", "both"))
+                cat("alpha:", -round(alpha, 4), "\n")
+            if (parameterization %in% c("slope", "both"))
+                cat("alphaD:", -round(Dalpha, 4), "\n")
             cat("sigma.t:", round(sigma.t, 4), "\n")
             cat("D:", if (!diag.D) round(D[lower.tri(D, TRUE)], 4) else round(D, 4), "\n")
         }
@@ -144,33 +181,37 @@ function (x, y, id, initial.values, scaleWB, control) {
         # M-step
         Zb <- rowSums(Z * post.b[id, ], na.rm = TRUE)
         mu <- y - eta.yx
-        tr.tZZvarb <- sum(ZtZ * post.vb, na.rm = TRUE)
+        tr.tZZvarb <- sum(ZtZ * post.vb, na.rm = TRUE)        
         sigman <- sqrt(c(crossprod(mu, mu - 2 * Zb) + crossprod(Zb) + tr.tZZvarb) / N)
         Dn <- matrix(colMeans(p.byt %*% (b2 * wGH), na.rm = TRUE), ncz, ncz)
-        Dn <- if (diag.D) diag(Dn) else 0.5 * (Dn + t(Dn))
+        Dn <- if (diag.D) diag(Dn) else 0.5 * (Dn + t(Dn))    
         Hbetas <- nearPD(fd.vec(betas, gr.longAFTWB))
         scbetas <- gr.longAFTWB(betas)
         betasn <- betas - c(solve(Hbetas, scbetas))
-        thetas <- if (is.null(scaleWB)) c(gammas, alpha, log(sigma.t)) else c(gammas, alpha)
+        list.thetas <- list(gammas = gammas, alpha = alpha, Dalpha = Dalpha, log.sigma.t = log(sigma.t))
+        if (!is.null(scaleWB))
+            list.thetas$log.sigma.t <- NULL
+        list.thetas <- list.thetas[!sapply(list.thetas, is.null)]
+        thetas <- unlist(as.relistable(list.thetas))
         optz.surv <- optim(thetas, opt.survAFTWB, gr.survAFTWB, method = "BFGS", 
             control = list(maxit = if (it < 5) 20 else 5, 
                 parscale = if (it < 10) rep(0.01, length(thetas)) else rep(0.1, length(thetas))))
-        thetasn <- optz.surv$par
+        thetasn <- relist(optz.surv$par, skeleton = list.thetas)
 
         # update parameter values
         betas <- betasn
         sigma <- sigman
         D <- Dn
-        gammas <- thetasn[1:ncww]
-        alpha <- thetasn[ncww + 1]
-        sigma.t <- if (is.null(scaleWB)) exp(thetasn[ncww + 2]) else scaleWB
+        gammas <- thetasn$gammas
+        alpha <- thetasn$alpha
+        Dalpha <- thetasn$Dalpha
+        sigma.t <- if (is.null(scaleWB)) exp(thetasn$log.sigma.t) else scaleWB        
     }
-    list.thetas <- list(betas = betas, log.sigma = log(sigma), gammas = gammas, alpha = alpha, 
-        log.sigma.t = log(sigma.t), D = if (diag.D) log(D) else chol.transf(D))
-    if (!is.null(scaleWB)) {
+    list.thetas <- list(betas = betas, log.sigma = log(sigma), gammas = gammas, alpha = alpha, Dalpha = Dalpha,
+        log.sigma.t = log(sigma.t), D = if (diag.D) log(D) else chol.transf(D))    
+    if (!is.null(scaleWB))
         list.thetas$log.sigma.t <- NULL
-        list.thetas <- list.thetas[!sapply(list.thetas, is.null)]
-    }
+    list.thetas <- list.thetas[!sapply(list.thetas, is.null)]
     thetas <- unlist(as.relistable(list.thetas))
     lgLik <- - LogLik.weibullAFTGH(thetas)
     
@@ -195,19 +236,27 @@ function (x, y, id, initial.values, scaleWB, control) {
             sigma <- exp(thetas$log.sigma)
             gammas <- thetas$gammas
             alpha <- thetas$alpha
+            Dalpha <- thetas$Dalpha
             sigma.t <- if (is.null(scaleWB)) exp(thetas$log.sigma.t) else scaleWB
             D <- thetas$D
             D <- if (diag.D) exp(D) else chol.transf(D)
             it <- it + if (control$optimizer == "optim") out$counts[1] else out$iterations
             # compute posterior moments for thetas after quasi-Newton
             eta.yx <- as.vector(X %*% betas)
-            eta.yxT <- as.vector(Xtime %*% betas)
             eta.tw <- as.vector(WW %*% gammas)
+            if (parameterization %in% c("value", "both")) {
+                Y <- as.vector(Xtime %*% betas) + Ztime.b
+                Ys <- as.vector(Xs %*% betas) + Zsb
+                eta.t <- eta.tw + alpha * Y
+                eta.s <- alpha * Ys
+            }
+            if (parameterization %in% c("slope", "both")) {
+                Y.deriv <- as.vector(Xtime.deriv %*% betas[indFixed]) + Ztime.b.deriv
+                Ys.deriv <- as.vector(Xs.deriv %*% betas[indFixed]) + Zsb.deriv
+                eta.t <- if (parameterization == "both") eta.t + Dalpha * Y.deriv else eta.tw + Dalpha * Y.deriv
+                eta.s <- if (parameterization == "both") eta.s + Dalpha * Ys.deriv else Dalpha * Ys.deriv
+            }
             exp.eta.tw <- exp(eta.tw)
-            Y <- eta.yxT + Ztime.b
-            Ys <- as.vector(Xs %*% betas) + Zsb
-            eta.t <- eta.tw + alpha * Y
-            eta.s <- alpha * Ys
             mu.y <- eta.yx + Ztb
             logNorm <- dnorm(y, mu.y, sigma, TRUE)
             log.p.yb <- rowsum(logNorm, id)
@@ -242,18 +291,23 @@ function (x, y, id, initial.values, scaleWB, control) {
         fd.vec(unlist(thetas), Score.weibullAFTGH, eps = control$eps.Hes)
     } else { 
         cd.vec(unlist(thetas), Score.weibullAFTGH, eps = control$eps.Hes)
-    }
+    }    
     names(betas) <- names(initial.values$betas)
     if (!diag.D) dimnames(D) <- dimnames(initial.values$D) else names(D) <- names(initial.values$D)
     names(gammas) <- c("(Intercept)", colnames(W1))
+    gg <- switch(parameterization, "value" = "alpha", "slope" = "alphaD", "both" = c("alpha", "alphaD"))
     nams <- c(paste("Y.", c(names(betas), "sigma"), sep = ""), 
-        paste("T.", if (is.null(scaleWB)) c(names(gammas), "alpha", "sigma.t") else c(names(gammas), "alpha"), sep = ""),
+        paste("T.", if (is.null(scaleWB)) c(names(gammas), gg, "sigma.t") else c(names(gammas), gg), sep = ""),
         paste("B.", if (!diag.D) paste("D", seq(1, ncz * (ncz + 1) / 2), sep = "") else names(D), sep = ""))
     dimnames(Hessian) <- list(nams, nams)
     colnames(post.b) <- colnames(x$Z)
-    list(coefficients = list(betas = betas, sigma = sigma, gammas = gammas, alpha = alpha, sigma.t = sigma.t, 
+    list(coefficients = list(betas = betas, sigma = sigma, gammas = gammas, alpha = alpha, Dalpha = Dalpha, sigma.t = sigma.t, 
         D = as.matrix(D)), Hessian = Hessian, logLik = lgLik, EB = list(post.b = post.b, post.vb = post.vb, 
         Zb = if (iter == 0) rowSums(Z * post.b[id, ], na.rm = TRUE) else Zb, 
-        Ztimeb = rowSums(Ztime * post.b)), iters = it, convergence = conv, n = n, N = N, ni = ni, d = d, id = id, scaleWB = scaleWB)
+        Ztimeb = if (parameterization %in% c("value", "both")) rowSums(Ztime * post.b) else NULL,
+        Ztimeb.deriv = if (parameterization %in% c("slope", "both")) {
+            if (indRandom) rowSums(Ztime.deriv * post.b[, indRandom, drop = FALSE]) else rep(0, nrow(Ztime.deriv))
+        } else NULL), 
+        iters = it, convergence = conv, n = n, N = N, ni = ni, d = d, id = id, scaleWB = scaleWB)
 }
 
